@@ -23,8 +23,8 @@
 #include "writer/structure/metaxml.h"
 #include "writer/structure/stylesxml.h"
 
-#include <quazip5/quazipfile.h>
-#include <quazip5/quacrc32.h>
+#include <quazipfile.h>
+#include <quacrc32.h>
 #include <QDebug>
 #include <QFileInfo>
 
