@@ -17,8 +17,7 @@
 
 */
 
-#ifndef TSVOUTPUTSTREAM_H
-#define TSVOUTPUTSTREAM_H
+#pragma once
 
 #include "tsvdirectorywriter.h"
 
@@ -41,4 +40,3 @@ class TsvOutputStream : public TsvDirectoryWriter
   bool _no_sheet_name = false;
 };
 
-#endif // TSVOUTPUTSTREAM_H
