@@ -21,7 +21,7 @@
 #include "metaxml.h"
 #include <QDateTime>
 #include "../../odsexception.h"
-#include <quazip5/quazipfile.h>
+#include <quazipfile.h>
 
 #define LIBODS_GENERATOR_NAME LIBODSSTREAM_LIB_NAME "/" LIBODSSTREAM_VERSION
 
