@@ -18,7 +18,7 @@
 */
 
 #pragma once
-#include <quazip5/quazip.h>
+#include <quazip.h>
 #include <QXmlStreamWriter>
 #include <QHash>
 
