@@ -235,8 +235,8 @@ Tsv2Ods::run()
   catch(OdsException &error)
     {
       errorStream << "Oops! an error occurred in tsv2ods. Don't Panic :"
-                  << endl;
-      errorStream << error.qwhat() << endl;
+                  << Qt::endl;
+      errorStream << error.qwhat() << Qt::endl;
       exit(1);
       app->exit(1);
     }
@@ -244,8 +244,8 @@ Tsv2Ods::run()
   catch(std::exception &error)
     {
       errorStream << "Oops! an error occurred in tsv2ods. Don't Panic :"
-                  << endl;
-      errorStream << error.what() << endl;
+                  << Qt::endl;
+      errorStream << error.what() << Qt::endl;
       exit(1);
       app->exit(1);
     }
