@@ -1,6 +1,12 @@
 
 #define CATCH_CONFIG_MAIN
+
+#ifdef CATCH2_MAJOR_VERSION_2
 #include <catch2/catch.hpp>
+#elif CATCH2_MAJOR_VERSION_3
+#include <catch2/catch_all.hpp>
+#endif
+
 #include "config.h"
 #include <QDebug>
 #include <iostream>
